==> scim-wnn-0.2.2.tar.gz: scim-wnn-0.2.2/src/romkan_table.h <==
/***************************************************************************
 *   Copyright (C) 2004 by TAM(Teppei Tamra)                               *
 *   tam-t@par.odn.ne.jp                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

// ޻Ѵơ֥롣
// ʤΤǥߥ/­βǽꡣ

const char _RomkanTable[][6] = {
//  "ɤ",   "Ѵ",
//  ("Ѵ"ξα"ɤ"ϥߥ͡)
    "a",    "",
    "i",    "",
    "u",    "",
    "e",    "",
    "o",    "",
    "k",    "",
    "ka",   "",
    "ki",   "",
    "ku",   "",
    "ke",   "",
    "ko",   "",
    "s",    "",
    "sa",   "",
    "si",   "",
    "su",   "",
    "se",   "",
    "so",   "",
    "t",    "",
    "ta",   "",
    "ti",   "",
    "tu",   "",
    "te",   "",
    "to",   "",
    "n",    "",
    "na",   "",
    "ni",   "",
    "nu",   "",
    "ne",   "",
    "no",   "",
    "h",    "",
    "ha",   "",
    "hi",   "",
    "hu",   "",
    "he",   "",
    "ho",   "",
    "m",    "",
    "ma",   "",
    "mi",   "",
    "mu",   "",
    "me",   "",
    "mo",   "",
    "y",    "",
    "ya",   "",
    "yi",   "",
    "yu",   "",
    "ye",   "",
    "yo",   "",
    "r",    "",
    "ra",   "",
    "ri",   "",
    "ru",   "",
    "re",   "",
    "ro",   "",
    "l",    "",
    "la",   "",
    "li",   "",
    "lu",   "",
    "le",   "",
    "lo",   "",
    "w",    "",
    "wa",   "",
    "wi",   "",
    "wu",   "",
    "we",   "",
    "wo",   "",
    "nn",   "",
    "N",    "",    // ʸN
    "x",    "",
    "xa",   "",
    "xi",   "",
    "xu",   "",
    "xe",   "",
    "xo",   "",
    "xt",   "",
    "xtu",  "",
    "xy",   "",
    "xya",  "",
    "xyu",  "",
    "xyo",  "",
    "g",    "",
    "ga",   "",
    "gi",   "",
    "gu",   "",
    "ge",   "",
    "go",   "",
    "z",    "",
    "za",   "",
    "zi",   "",
    "zu",   "",
    "ze",   "",
    "zo",   "",
    "d",    "",
    "da",   "",
    "di",   "",
    "du",   "",
    "de",   "",
    "do",   "",
    "b",    "",
    "ba",   "",
    "bi",   "",
    "bu",   "",
    "be",   "",
    "bo",   "",
    "p",    "",
    "pa",   "",
    "pi",   "",
    "pu",   "",
    "pe",   "",
    "po",   "",
    "ky",   "",
    "kya",  "",
    "kyi",  "",
    "kyu",  "",
    "kye",  "",
    "kyo",  "",
    "sy",   "",
    "sya",  "",
    "syi",  "",
    "syu",  "",
    "sye",  "",
    "syo",  "",
    "sh",   "",
    "sha",  "",
    "shi",  "",
    "shu",  "",
    "she",  "",
    "sho",  "",
    "c",    "",
    "ch",   "",
    "cha",  "",
    "chi",  "",
    "chu",  "",
    "che",  "",
    "cho",  "",
    "ty",   "",
    "tya",  "",
    "tyi",  "Ƥ",
    "tyu",  "",
    "tye",  "",
    "tyo",  "",
    "dy",   "",
    "dya",  "¤",
    "dyi",  "Ǥ",
    "dyu",  "¤",
    "dye",  "¤",
    "dyo",  "¤",
    "v",    "",
    "va",   "",
    "vi",   "",
    "vu",   "",
    "ve",   "",
    "vo",   "",
    "zy",   "",
    "zya",  "",
    "zyi",  "",
    "zyu",  "",
    "zye",  "",
    "zyo",  "",
    "j",    "",
    "ja",   "",
    "ji",   "",
    "ju",   "",
    "je",   "",
    "jo",   "",
    "f",    "",
    "fa",   "դ",
    "fi",   "դ",
    "fu",   "",
    "fe",   "դ",
    "fo",   "դ",
    "hy",   "",
    "hya",  "Ҥ",
    "hyi",  "Ҥ",
    "hyu",  "Ҥ",
    "hye",  "Ҥ",
    "hyo",  "Ҥ",
    "ry",   "",
    "rya",  "",
    "ryi",  "ꤣ",
    "ryu",  "",
    "rye",  "ꤧ",
    "ryo",  "",
    "ny",   "",
    "nya",  "ˤ",
    "nyi",  "ˤ",
    "nyu",  "ˤ",
    "nye",  "ˤ",
    "nyo",  "ˤ",
    "gy",   "",
    "gya",  "",
    "gyi",  "",
    "gyu",  "",
    "gye",  "",
    "gyo",  "",
    "py",   "",
    "pya",  "Ԥ",
    "pyi",  "Ԥ",
    "pyu",  "Ԥ",
    "pye",  "Ԥ",
    "pyo",  "Ԥ",
    "my",   "",
    "mya",  "ߤ",
    "myi",  "ߤ",
    "myu",  "ߤ",
    "mye",  "ߤ",
    "myo",  "ߤ",
    "Z",    "",
    "Za",   "",
    "Zb",   "",
    "Zc",   "",
    "Zd",   "",
    "Ze",   "",
    "Zf",   "",
    "Zg",   "",
    "Zh",   "",
    "Zi",   "",
    "Zj",   "",
    "Zk",   "",
    "Zl",   "",
    "Zm",   "",
    "Zn",   "",
    "Zo",   "",
    "Zp",   "",
    "Zq",   "",
    "Zr",   "",
    "Zs",   "",
    "Zt",   "",
    "Zu",   "",
    "Zv",   "",
    "Zw",   "",
    "Zx",   "",
    "Zy",   "",
    "Zz",   "",
    "ZA",   "",
    "ZB",   "",
    "ZC",   "",
    "ZD",   "",
    "ZE",   "",
    "ZF",   "",
    "ZG",   "",
    "ZH",   "",
    "ZI",   "",
    "ZJ",   "",
    "ZK",   "",
    "ZL",   "",
    "ZM",   "",
    "ZN",   "",
    "ZO",   "",
    "ZP",   "",
    "ZQ",   "",
    "ZR",   "",
    "ZS",   "",
    "ZT",   "",
    "ZU",   "",
    "ZV",   "",
    "ZW",   "",
    "ZX",   "",
    "ZY",   "",
    "ZZ",   "",
    "Z1",   "",
    "Z2",   "",
    "Z3",   "",
    "Z4",   "",
    "Z5",   "",
    "Z6",   "",
    "Z7",   "",
    "Z8",   "",
    "Z9",   "",
    "Z0",   "",

    "Z-",   "",
    "Z^",   "",
    "Z\\",   "",
    "z1",   "",
    "z2",   "",
    "z3",   "",
    "z4",   "",
    "z5",   "",
    "z6",   "",
    "z7",   "",
    "z8",   "",
    "z9",   "",
    "z0",   "",
    "z-",   "",
    "z^",   "",
    "z\\",   "",
    "z,",   "",
    "z.",   "",
    "z/",   "",

    "-",    "",
    "[",    "",
    "]",    "",
    ".",    "",
    ",",    "",
    "{",    "",
    "}",    "",
    "@",    "",
    ":",    "",
    ";",    "",
    "?",    "",
    "<",    "",
    ">",    "",
    "*",    "",
    "+",    "",
    "/",    "",
    "\\",   "",

    "z-",   "",
    "z[",   "",
    "z]",   "",
    "z.",   "",
    "z,",   "",
    "z{",   "",
    "z}",   "",
    "z@",   "",
    "z:",   "",
    "z;",   "",
    "z?",   "",
    "z<",   "",
    "z>",   "",
    "z*",   "",
    "z+",   "",
    "z/",   "",
    "z\\",  "",

    "Z-",   "",
    "Z[",   "",
    "Z]",   "",
    "Z.",   "",
    "Z,",   "",
    "Z{",   "",
    "Z}",   "",
    "Z@",   "",
    "Z:",   "",
    "Z;",   "",
    "Z?",   "",
    "Z<",   "",
    "Z>",   "",
    "Z*",   "",
    "Z+",   "",
    "Z/",   "",
    "Z\\",  "",
    "Z ",   "",

    "zb",   "",
    "zc",   "",
    "zd",   "",
    "zf",   "",
    "zg",   "",
    "zh",   "",
    "zj",   "",
    "zk",   "",
    "zl",   "",
    "zm",   "",
    "zn",   "",
    "zp",   "",
    "zq",   "",
    "zr",   "",
    "zs",   "",
    "zt",   "",
    "zv",   "",
    "zw",   "",
    "zx",   ":-",
    ""
};

==> scim-wnn-1.0.0.tar.gz: scim-wnn-1.0.0/src/romkan_table.h <==
/***************************************************************************
 *   Copyright (C) 2004 by TAM(Teppei Tamra)                               *
 *   tam-t@par.odn.ne.jp                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

// ޻Ѵơ֥롣
// ʤΤǥߥ/­βǽꡣ

const char _RomkanTable[][6] = {
//  "ɤ",   "Ѵ",
//  ("Ѵ"ξα"ɤ"ϥߥ͡)
    "a",    "",
    "i",    "",
    "u",    "",
    "e",    "",
    "o",    "",
    "ka",   "",
    "ki",   "",
    "ku",   "",
    "ke",   "",
    "ko",   "",
    "sa",   "",
    "si",   "",
    "su",   "",
    "se",   "",
    "so",   "",
    "ta",   "",
    "ti",   "",
    "tu",   "",
    "te",   "",
    "to",   "",
    "na",   "",
    "ni",   "",
    "nu",   "",
    "ne",   "",
    "no",   "",
    "ha",   "",
    "hi",   "",
    "hu",   "",
    "he",   "",
    "ho",   "",
    "ma",   "",
    "mi",   "",
    "mu",   "",
    "me",   "",
    "mo",   "",
    "ya",   "",
    "yi",   "",
    "yu",   "",
    "ye",   "",
    "yo",   "",
    "ra",   "",
    "ri",   "",
    "ru",   "",
    "re",   "",
    "ro",   "",
    "la",   "",
    "li",   "",
    "lu",   "",
    "le",   "",
    "lo",   "",
    "wa",   "",
    "wi",   "",
    "wu",   "",
    "we",   "",
    "wo",   "",
    "nn",   "",
    "N",    "",    // ʸN
    "xa",   "",
    "xi",   "",
    "xu",   "",
    "xe",   "",
    "xo",   "",
    "xtu",  "",
    "xya",  "",
    "xyu",  "",
    "xyo",  "",
    "ga",   "",
    "gi",   "",
    "gu",   "",
    "ge",   "",
    "go",   "",
    "za",   "",
    "zi",   "",
    "zu",   "",
    "ze",   "",
    "zo",   "",
    "da",   "",
    "di",   "",
    "du",   "",
    "de",   "",
    "do",   "",
    "ba",   "",
    "bi",   "",
    "bu",   "",
    "be",   "",
    "bo",   "",
    "pa",   "",
    "pi",   "",
    "pu",   "",
    "pe",   "",
    "po",   "",
    "kya",  "",
    "kyi",  "",
    "kyu",  "",
    "kye",  "",
    "kyo",  "",
    "sya",  "",
    "syi",  "",
    "syu",  "",
    "sye",  "",
    "syo",  "",
    "sha",  "",
    "shi",  "",
    "shu",  "",
    "she",  "",
    "sho",  "",
    "cha",  "",
    "chi",  "",
    "chu",  "",
    "che",  "",
    "cho",  "",
    "tya",  "",
    "tyi",  "Ƥ",
    "tyu",  "",
    "tye",  "",
    "tyo",  "",
    "dya",  "¤",
    "dyi",  "Ǥ",
    "dyu",  "¤",
    "dye",  "¤",
    "dyo",  "¤",
    "va",   "",
    "vi",   "",
    "vu",   "",
    "ve",   "",
    "vo",   "",
    "zya",  "",
    "zyi",  "",
    "zyu",  "",
    "zye",  "",
    "zyo",  "",
    "ja",   "",
    "ji",   "",
    "ju",   "",
    "je",   "",
    "jo",   "",
    "fa",   "դ",
    "fi",   "դ",
    "fu",   "",
    "fe",   "դ",
    "fo",   "դ",
    "hya",  "Ҥ",
    "hyi",  "Ҥ",
    "hyu",  "Ҥ",
    "hye",  "Ҥ",
    "hyo",  "Ҥ",
    "rya",  "",
    "ryi",  "ꤣ",
    "ryu",  "",
    "rye",  "ꤧ",
    "ryo",  "",
    "nya",  "ˤ",
    "nyi",  "ˤ",
    "nyu",  "ˤ",
    "nye",  "ˤ",
    "nyo",  "ˤ",
    "gya",  "",
    "gyi",  "",
    "gyu",  "",
    "gye",  "",
    "gyo",  "",
    "bya",  "Ӥ",
    "byi",  "Ӥ",
    "byu",  "Ӥ",
    "bye",  "Ӥ",
    "byo",  "Ӥ",
    "pya",  "Ԥ",
    "pyi",  "Ԥ",
    "pyu",  "Ԥ",
    "pye",  "Ԥ",
    "pyo",  "Ԥ",
    "mya",  "ߤ",
    "myi",  "ߤ",
    "myu",  "ߤ",
    "mye",  "ߤ",
    "myo",  "ߤ",
    "Za",   "",
    "Zb",   "",
    "Zc",   "",
    "Zd",   "",
    "Ze",   "",
    "Zf",   "",
    "Zg",   "",
    "Zh",   "",
    "Zi",   "",
    "Zj",   "",
    "Zk",   "",
    "Zl",   "",
    "Zm",   "",
    "Zn",   "",
    "Zo",   "",
    "Zp",   "",
    "Zq",   "",
    "Zr",   "",
    "Zs",   "",
    "Zt",   "",
    "Zu",   "",
    "Zv",   "",
    "Zw",   "",
    "Zx",   "",
    "Zy",   "",
    "Zz",   "",
    "ZA",   "",
    "ZB",   "",
    "ZC",   "",
    "ZD",   "",
    "ZE",   "",
    "ZF",   "",
    "ZG",   "",
    "ZH",   "",
    "ZI",   "",
    "ZJ",   "",
    "ZK",   "",
    "ZL",   "",
    "ZM",   "",
    "ZN",   "",
    "ZO",   "",
    "ZP",   "",
    "ZQ",   "",
    "ZR",   "",
    "ZS",   "",
    "ZT",   "",
    "ZU",   "",
    "ZV",   "",
    "ZW",   "",
    "ZX",   "",
    "ZY",   "",
    "ZZ",   "",
    "Z1",   "",
    "Z2",   "",
    "Z3",   "",
    "Z4",   "",
    "Z5",   "",
    "Z6",   "",
    "Z7",   "",
    "Z8",   "",
    "Z9",   "",
    "Z0",   "",

    //"Z-",   "",
    "Z^",   "",
    //"Z\\",   "",
    "z1",   "",
    "z2",   "",
    "z3",   "",
    "z4",   "",
    "z5",   "",
    "z6",   "",
    "z7",   "",
    "z8",   "",
    "z9",   "",
    "z0",   "",
    "z-",   "",
    "z^",   "",
    "z\\",   "",
    "z,",   "",
    "z.",   "",
    "z/",   "",

    "-",    "",
    "[",    "",
    "]",    "",
    ".",    "",
    ",",    "",
    "{",    "",
    "}",    "",
    "@",    "",
    ":",    "",
    ";",    "",
    "?",    "",
    "<",    "",
    ">",    "",
    "*",    "",
    "+",    "",
    "/",    "",
    "\\",   "",

    "z-",   "",
    "z[",   "",
    "z]",   "",
    "z.",   "",
    "z,",   "",
    "z{",   "",
    "z}",   "",
    "z@",   "",
    "z:",   "",
    "z;",   "",
    "z?",   "",
    "z<",   "",
    "z>",   "",
    "z*",   "",
    "z+",   "",
    "z/",   "",
    //"z\\",  "",

    "Z-",   "",
    "Z[",   "",
    "Z]",   "",
    "Z.",   "",
    "Z,",   "",
    "Z{",   "",
    "Z}",   "",
    "Z@",   "",
    "Z:",   "",
    "Z;",   "",
    "Z?",   "",
    "Z<",   "",
    "Z>",   "",
    "Z*",   "",
    "Z+",   "",
    "Z/",   "",
    "Z\\",  "",
    "Z ",   "",

    "zb",   "",
    "zc",   "",
    "zd",   "",
    "zf",   "",
    "zg",   "",
    "zh",   "",
    "zj",   "",
    "zk",   "",
    "zl",   "",
    "zm",   "",
    "zn",   "",
    "zp",   "",
    "zq",   "",
    "zr",   "",
    "zs",   "",
    "zt",   "",
    "zv",   "",
    "zw",   "",
    "zx",   ":-",
    ""
};
